@@ -26,17 +26,9 @@ class wallet:
             for item in items:
                 wallet = int(item[1])
                 bank = int(item[2])
-            
-            print("--------")    
-            print(wallet)
-            print(self.amount)
                 
             sum = self.amount + wallet
             
-            print(sum)
-            print(self.user_ID)
-            print("-------------")
-            
             c.execute(f"""UPDATE economy SET wallet = {sum}
                     WHERE user_ID = {self.user_ID}  
                 """)
